==> financial-settlement-service-0.1.273-sources.jar: com/xforceplus/ultraman/app/financialsettlement/controller/AllocationRuleDetailsController.java <==
package com.xforceplus.ultraman.app.financialsettlement.controller;


import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.xforceplus.ultraman.bocp.gen.plugins.XfPage;
import org.springframework.web.bind.annotation.*;
import org.springframework.beans.factory.annotation.Autowired;
import com.xforceplus.ultraman.bocp.gen.api.XfR;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.ultraman.app.financialsettlement.entity.AllocationRuleDetails;
import com.xforceplus.ultraman.app.financialsettlement.service.IAllocationRuleDetailsService;
import lombok.AllArgsConstructor;
import com.xforceplus.ultraman.bocp.gen.util.ObjectCopyUtils;
import com.xforceplus.ultraman.bocp.gen.sql.pojo.ConditionQueryRequest;
import java.util.HashMap;
import java.util.Map;
import org.springframework.stereotype.Controller;
/**
 * 分摊规则明细前端控制器
 *
 * @author ultraman
 * @date 2022-09-29
 */
@RestController
public class AllocationRuleDetailsController {

  @Autowired
  private IAllocationRuleDetailsService allocationRuleDetailsServiceImpl;


  /**
   * 查询所有-分页模式
   * @param page 分页对象
   * @param allocationRuleDetails 分摊规则明细
   * @return
   */
  @GetMapping("/allocationruledetailss" )
  public XfR getAllocationRuleDetailss(XfPage page, AllocationRuleDetails allocationRuleDetails) {
    return XfR.ok(allocationRuleDetailsServiceImpl.page(page, Wrappers.query(allocationRuleDetails)));
  }

  /**
   * 通过id查询分摊规则明细
   * @param  id
   * @return XfR
   */
  @GetMapping("/allocationruledetailss/{id}")
  public XfR getById(@PathVariable Long id) {
     return XfR.ok(allocationRuleDetailsServiceImpl.getById(id));
  }

  /**
   * 新增分摊规则明细
   * @param allocationRuleDetails 分摊规则明细
   * @return XfR
   */
  @PostMapping("/allocationruledetailss")
  public XfR save(@RequestBody AllocationRuleDetails allocationRuleDetails) {
     return XfR.ok(allocationRuleDetailsServiceImpl.save(allocationRuleDetails));
  }

  /**
   * 修改-传入修改后的全部数据分摊规则明细
   * @param allocationRuleDetails 分摊规则明细
   * @return XfR
   */
  @PutMapping("/allocationruledetailss/{id}")
  public XfR putUpdate(@RequestBody AllocationRuleDetails allocationRuleDetails,@PathVariable Long id) {
      allocationRuleDetails.setId(id);
      return XfR.ok(allocationRuleDetailsServiceImpl.updateById(allocationRuleDetails));
  }

  /**
   * 修改-传入修改的数据分摊规则明细
   * @param allocationRuleDetails 分摊规则明细
   * @return XfR
   */
  @PatchMapping("/allocationruledetailss/{id}")
  public XfR patchUpdate(@RequestBody AllocationRuleDetails allocationRuleDetails,@PathVariable Long id) {
      AllocationRuleDetails upallocationRuleDetails = allocationRuleDetailsServiceImpl.getById(id);
      if(upallocationRuleDetails != null){
        upallocationRuleDetails = ObjectCopyUtils.copyProperties(allocationRuleDetails,upallocationRuleDetails,true);
      }
      return XfR.ok(allocationRuleDetailsServiceImpl.updateById(upallocationRuleDetails));
  }

  /**
   * 通过id删除分摊规则明细
   * @param  id
   * @return XfR
   */
  @DeleteMapping("/allocationruledetailss/{id}")
  public XfR removeById(@PathVariable Long id) {
     return XfR.ok(allocationRuleDetailsServiceImpl.removeById(id));
  }

  @PostMapping("/allocationruledetailss/query")
  public XfR querys(@RequestBody ConditionQueryRequest condition) {
     Map<String, Object> params = new HashMap();
     params.put("tableName", "allocation_rule_details");
     params.put("request", condition);

     return XfR.ok(allocationRuleDetailsServiceImpl.querys(params));
  }

}

==> financial-settlement-service-0.1.318-sources.jar: com/xforceplus/ultraman/app/financialsettlement/controller/AllocationRuleDetailsController.java <==
package com.xforceplus.ultraman.app.financialsettlement.controller;


import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.xforceplus.ultraman.bocp.gen.plugins.XfPage;
import org.springframework.web.bind.annotation.*;
import org.springframework.beans.factory.annotation.Autowired;
import com.xforceplus.ultraman.bocp.gen.api.XfR;
import org.apache.commons.lang3.StringUtils;
import com.xforceplus.ultraman.app.financialsettlement.entity.AllocationRuleDetails;
import com.xforceplus.ultraman.app.financialsettlement.service.IAllocationRuleDetailsService;
import lombok.AllArgsConstructor;
import com.xforceplus.ultraman.bocp.gen.util.ObjectCopyUtils;
import com.xforceplus.ultraman.bocp.gen.sql.pojo.ConditionQueryRequest;
import java.util.HashMap;
import java.util.Map;
import org.springframework.stereotype.Controller;
/**
 * 分摊规则明细前端控制器
 *
 * @author ultraman
 * @date 2023-03-08
 */
@RestController
public class AllocationRuleDetailsController {

  @Autowired
  private IAllocationRuleDetailsService allocationRuleDetailsServiceImpl;


  /**
   * 查询所有-分页模式
   * @param page 分页对象
   * @param allocationRuleDetails 分摊规则明细
   * @return
   */
  @GetMapping("/allocationruledetailss" )
  public XfR getAllocationRuleDetailss(XfPage page, AllocationRuleDetails allocationRuleDetails) {
    return XfR.ok(allocationRuleDetailsServiceImpl.page(page, Wrappers.query(allocationRuleDetails)));
  }

  /**
   * 通过id查询分摊规则明细
   * @param  id
   * @return XfR
   */
  @GetMapping("/allocationruledetailss/{id}")
  public XfR getById(@PathVariable Long id) {
     return XfR.ok(allocationRuleDetailsServiceImpl.getById(id));
  }

  /**
   * 新增分摊规则明细
   * @param allocationRuleDetails 分摊规则明细
   * @return XfR
   */
  @PostMapping("/allocationruledetailss")
  public XfR save(@RequestBody AllocationRuleDetails allocationRuleDetails) {
     return XfR.ok(allocationRuleDetailsServiceImpl.save(allocationRuleDetails));
  }

  /**
   * 修改-传入修改后的全部数据分摊规则明细
   * @param allocationRuleDetails 分摊规则明细
   * @return XfR
   */
  @PutMapping("/allocationruledetailss/{id}")
  public XfR putUpdate(@RequestBody AllocationRuleDetails allocationRuleDetails,@PathVariable Long id) {
      allocationRuleDetails.setId(id);
      return XfR.ok(allocationRuleDetailsServiceImpl.updateById(allocationRuleDetails));
  }

  /**
   * 修改-传入修改的数据分摊规则明细
   * @param allocationRuleDetails 分摊规则明细
   * @return XfR
   */
  @PatchMapping("/allocationruledetailss/{id}")
  public XfR patchUpdate(@RequestBody AllocationRuleDetails allocationRuleDetails,@PathVariable Long id) {
      AllocationRuleDetails upallocationRuleDetails = allocationRuleDetailsServiceImpl.getById(id);
      if(upallocationRuleDetails != null){
        upallocationRuleDetails = ObjectCopyUtils.copyProperties(allocationRuleDetails,upallocationRuleDetails,true);
      }
      return XfR.ok(allocationRuleDetailsServiceImpl.updateById(upallocationRuleDetails));
  }

  /**
   * 通过id删除分摊规则明细
   * @param  id
   * @return XfR
   */
  @DeleteMapping("/allocationruledetailss/{id}")
  public XfR removeById(@PathVariable Long id) {
     return XfR.ok(allocationRuleDetailsServiceImpl.removeById(id));
  }

  @PostMapping("/allocationruledetailss/query")
  public XfR querys(@RequestBody ConditionQueryRequest condition) {
     Map<String, Object> params = new HashMap();
     params.put("tableName", "allocation_rule_details");
     params.put("request", condition);

     return XfR.ok(allocationRuleDetailsServiceImpl.querys(params));
  }

}
